Modules
SeaORMEntity, @generated by sea-orm-codegen 1.0.0
Functions
- Deletes previous runs .stdout and .stderr Stdout and stderr capturing are append due to a scenario / observeration removing previous ones stdout and err
- Attempts to find the users CPU automatically and asks the user to enter it manually if that fails.